# File generated from our OpenAPI spec by Stainless. See CONTRIBUTING.md for details.

from .user import (
    UserResource,
    AsyncUserResource,
    UserResourceWithRawResponse,
    AsyncUserResourceWithRawResponse,
    UserResourceWithStreamingResponse,
    AsyncUserResourceWithStreamingResponse,
)
from .settings import (
    SettingsResource,
    AsyncSettingsResource,
    SettingsResourceWithRawResponse,
    AsyncSettingsResourceWithRawResponse,
    SettingsResourceWithStreamingResponse,
    AsyncSettingsResourceWithStreamingResponse,
)

__all__ = [
    "SettingsResource",
    "AsyncSettingsResource",
    "SettingsResourceWithRawResponse",
    "AsyncSettingsResourceWithRawResponse",
    "SettingsResourceWithStreamingResponse",
    "AsyncSettingsResourceWithStreamingResponse",
    "UserResource",
    "AsyncUserResource",
    "UserResourceWithRawResponse",
    "AsyncUserResourceWithRawResponse",
    "UserResourceWithStreamingResponse",
    "AsyncUserResourceWithStreamingResponse",
]



# File generated from our OpenAPI spec by Stainless. See CONTRIBUTING.md for details.

from __future__ import annotations

import httpx

from ..._types import Body, Query, Headers, NotGiven, not_given
from ..._compat import cached_property
from ..._resource import SyncAPIResource, AsyncAPIResource
from ..._response import (
    to_raw_response_wrapper,
    to_streamed_response_wrapper,
    async_to_raw_response_wrapper,
    async_to_streamed_response_wrapper,
)
from ..._base_client import make_request_options
from ...types.api.health_check_app_response import HealthCheckAppResponse
from ...types.api.health_get_models_response import HealthGetModelsResponse
from ...types.api.health_check_models_response import HealthCheckModelsResponse
from ...types.api.health_check_services_response import HealthCheckServicesResponse
from ...types.api.health_retrieve_status_response import HealthRetrieveStatusResponse
from ...types.api.health_retrieve_version_response import HealthRetrieveVersionResponse

__all__ = ["HealthResource", "AsyncHealthResource"]


class HealthResource(SyncAPIResource):
    @cached_property
    def with_raw_response(self) -> HealthResourceWithRawResponse:
        """
        This property can be used as a prefix for any HTTP method call to return
        the raw response object instead of the parsed content.

        For more information, see https://www.github.com/arbitrationcity/arbi-python#accessing-raw-response-data-eg-headers
        """
        return HealthResourceWithRawResponse(self)

    @cached_property
    def with_streaming_response(self) -> HealthResourceWithStreamingResponse:
        """
        An alternative to `.with_raw_response` that doesn't eagerly read the response body.

        For more information, see https://www.github.com/arbitrationcity/arbi-python#with_streaming_response
        """
        return HealthResourceWithStreamingResponse(self)

    def check_app(
        self,
        *,
        # Use the following arguments if you need to pass additional parameters to the API that aren't available via kwargs.
        # The extra values given here take precedence over values defined on the client or passed to this method.
        extra_headers: Headers | None = None,
        extra_query: Query | None = None,
        extra_body: Body | None = None,
        timeout: float | httpx.Timeout | None | NotGiven = not_given,
    ) -> HealthCheckAppResponse:
        """Lightweight health check endpoint for the arbi-app itself.

        Returns version
        information along with health status.
        """
        return self._get(
            "/api/health/app",
            options=make_request_options(
                extra_headers=extra_headers, extra_query=extra_query, extra_body=extra_body, timeout=timeout
            ),
            cast_to=HealthCheckAppResponse,
        )

    def check_models(
        self,
        *,
        # Use the following arguments if you need to pass additional parameters to the API that aren't available via kwargs.
        # The extra values given here take precedence over values defined on the client or passed to this method.
        extra_headers: Headers | None = None,
        extra_query: Query | None = None,
        extra_body: Body | None = None,
        timeout: float | httpx.Timeout | None | NotGiven = not_given,
    ) -> HealthCheckModelsResponse:
        """
        Endpoint to check the health of various models hosted on the LiteLLM platform.
        This endpoint fetches a list of available models and checks if each one is
        operational.
        """
        return self._get(
            "/api/health/remote-models",
            options=make_request_options(
                extra_headers=extra_headers, extra_query=extra_query, extra_body=extra_body, timeout=timeout
            ),
            cast_to=HealthCheckModelsResponse,
        )

    def check_services(
        self,
        *,
        # Use the following arguments if you need to pass additional parameters to the API that aren't available via kwargs.
        # The extra values given here take precedence over values defined on the client or passed to this method.
        extra_headers: Headers | None = None,
        extra_query: Query | None = None,
        extra_body: Body | None = None,
        timeout: float | httpx.Timeout | None | NotGiven = not_given,
    ) -> HealthCheckServicesResponse:
        """
        Health check endpoint that verifies the status of the application and external
        services. Always returns a structured object with the health status of all
        services.
        """
        return self._get(
            "/api/health/services",
            options=make_request_options(
                extra_headers=extra_headers, extra_query=extra_query, extra_body=extra_body, timeout=timeout
            ),
            cast_to=HealthCheckServicesResponse,
        )

    def get_models(
        self,
        *,
        # Use the following arguments if you need to pass additional parameters to the API that aren't available via kwargs.
        # The extra values given here take precedence over values defined on the client or passed to this method.
        extra_headers: Headers | None = None,
        extra_query: Query | None = None,
        extra_body: Body | None = None,
        timeout: float | httpx.Timeout | None | NotGiven = not_given,
    ) -> HealthGetModelsResponse:
        """Returns available models with model_name and api_type fields"""
        return self._get(
            "/api/health/models",
            options=make_request_options(
                extra_headers=extra_headers, extra_query=extra_query, extra_body=extra_body, timeout=timeout
            ),
            cast_to=HealthGetModelsResponse,
        )

    def retrieve_status(
        self,
        *,
        # Use the following arguments if you need to pass additional parameters to the API that aren't available via kwargs.
        # The extra values given here take precedence over values defined on the client or passed to this method.
        extra_headers: Headers | None = None,
        extra_query: Query | None = None,
        extra_body: Body | None = None,
        timeout: float | httpx.Timeout | None | NotGiven = not_given,
    ) -> HealthRetrieveStatusResponse:
        """
        Consolidated health endpoint that returns status, version information, and
        service health. This combines the functionality of /app, /version, and /services
        endpoints.
        """
        return self._get(
            "/api/health/",
            options=make_request_options(
                extra_headers=extra_headers, extra_query=extra_query, extra_body=extra_body, timeout=timeout
            ),
            cast_to=HealthRetrieveStatusResponse,
        )

    def retrieve_version(
        self,
        *,
        # Use the following arguments if you need to pass additional parameters to the API that aren't available via kwargs.
        # The extra values given here take precedence over values defined on the client or passed to this method.
        extra_headers: Headers | None = None,
        extra_query: Query | None = None,
        extra_body: Body | None = None,
        timeout: float | httpx.Timeout | None | NotGiven = not_given,
    ) -> HealthRetrieveVersionResponse:
        """Get version information for backend and frontend components."""
        return self._get(
            "/api/health/version",
            options=make_request_options(
                extra_headers=extra_headers, extra_query=extra_query, extra_body=extra_body, timeout=timeout
            ),
            cast_to=HealthRetrieveVersionResponse,
        )


class AsyncHealthResource(AsyncAPIResource):
    @cached_property
    def with_raw_response(self) -> AsyncHealthResourceWithRawResponse:
        """
        This property can be used as a prefix for any HTTP method call to return
        the raw response object instead of the parsed content.

        For more information, see https://www.github.com/arbitrationcity/arbi-python#accessing-raw-response-data-eg-headers
        """
        return AsyncHealthResourceWithRawResponse(self)

    @cached_property
    def with_streaming_response(self) -> AsyncHealthResourceWithStreamingResponse:
        """
        An alternative to `.with_raw_response` that doesn't eagerly read the response body.

        For more information, see https://www.github.com/arbitrationcity/arbi-python#with_streaming_response
        """
        return AsyncHealthResourceWithStreamingResponse(self)

    async def check_app(
        self,
        *,
        # Use the following arguments if you need to pass additional parameters to the API that aren't available via kwargs.
        # The extra values given here take precedence over values defined on the client or passed to this method.
        extra_headers: Headers | None = None,
        extra_query: Query | None = None,
        extra_body: Body | None = None,
        timeout: float | httpx.Timeout | None | NotGiven = not_given,
    ) -> HealthCheckAppResponse:
        """Lightweight health check endpoint for the arbi-app itself.

        Returns version
        information along with health status.
        """
        return await self._get(
            "/api/health/app",
            options=make_request_options(
                extra_headers=extra_headers, extra_query=extra_query, extra_body=extra_body, timeout=timeout
            ),
            cast_to=HealthCheckAppResponse,
        )

    async def check_models(
        self,
        *,
        # Use the following arguments if you need to pass additional parameters to the API that aren't available via kwargs.
        # The extra values given here take precedence over values defined on the client or passed to this method.
        extra_headers: Headers | None = None,
        extra_query: Query | None = None,
        extra_body: Body | None = None,
        timeout: float | httpx.Timeout | None | NotGiven = not_given,
    ) -> HealthCheckModelsResponse:
        """
        Endpoint to check the health of various models hosted on the LiteLLM platform.
        This endpoint fetches a list of available models and checks if each one is
        operational.
        """
        return await self._get(
            "/api/health/remote-models",
            options=make_request_options(
                extra_headers=extra_headers, extra_query=extra_query, extra_body=extra_body, timeout=timeout
            ),
            cast_to=HealthCheckModelsResponse,
        )

    async def check_services(
        self,
        *,
        # Use the following arguments if you need to pass additional parameters to the API that aren't available via kwargs.
        # The extra values given here take precedence over values defined on the client or passed to this method.
        extra_headers: Headers | None = None,
        extra_query: Query | None = None,
        extra_body: Body | None = None,
        timeout: float | httpx.Timeout | None | NotGiven = not_given,
    ) -> HealthCheckServicesResponse:
        """
        Health check endpoint that verifies the status of the application and external
        services. Always returns a structured object with the health status of all
        services.
        """
        return await self._get(
            "/api/health/services",
            options=make_request_options(
                extra_headers=extra_headers, extra_query=extra_query, extra_body=extra_body, timeout=timeout
            ),
            cast_to=HealthCheckServicesResponse,
        )

    async def get_models(
        self,
        *,
        # Use the following arguments if you need to pass additional parameters to the API that aren't available via kwargs.
        # The extra values given here take precedence over values defined on the client or passed to this method.
        extra_headers: Headers | None = None,
        extra_query: Query | None = None,
        extra_body: Body | None = None,
        timeout: float | httpx.Timeout | None | NotGiven = not_given,
    ) -> HealthGetModelsResponse:
        """Returns available models with model_name and api_type fields"""
        return await self._get(
            "/api/health/models",
            options=make_request_options(
                extra_headers=extra_headers, extra_query=extra_query, extra_body=extra_body, timeout=timeout
            ),
            cast_to=HealthGetModelsResponse,
        )

    async def retrieve_status(
        self,
        *,
        # Use the following arguments if you need to pass additional parameters to the API that aren't available via kwargs.
        # The extra values given here take precedence over values defined on the client or passed to this method.
        extra_headers: Headers | None = None,
        extra_query: Query | None = None,
        extra_body: Body | None = None,
        timeout: float | httpx.Timeout | None | NotGiven = not_given,
    ) -> HealthRetrieveStatusResponse:
        """
        Consolidated health endpoint that returns status, version information, and
        service health. This combines the functionality of /app, /version, and /services
        endpoints.
        """
        return await self._get(
            "/api/health/",
            options=make_request_options(
                extra_headers=extra_headers, extra_query=extra_query, extra_body=extra_body, timeout=timeout
            ),
            cast_to=HealthRetrieveStatusResponse,
        )

    async def retrieve_version(
        self,
        *,
        # Use the following arguments if you need to pass additional parameters to the API that aren't available via kwargs.
        # The extra values given here take precedence over values defined on the client or passed to this method.
        extra_headers: Headers | None = None,
        extra_query: Query | None = None,
        extra_body: Body | None = None,
        timeout: float | httpx.Timeout | None | NotGiven = not_given,
    ) -> HealthRetrieveVersionResponse:
        """Get version information for backend and frontend components."""
        return await self._get(
            "/api/health/version",
            options=make_request_options(
                extra_headers=extra_headers, extra_query=extra_query, extra_body=extra_body, timeout=timeout
            ),
            cast_to=HealthRetrieveVersionResponse,
        )


class HealthResourceWithRawResponse:
    def __init__(self, health: HealthResource) -> None:
        self._health = health

        self.check_app = to_raw_response_wrapper(
            health.check_app,
        )
        self.check_models = to_raw_response_wrapper(
            health.check_models,
        )
        self.check_services = to_raw_response_wrapper(
            health.check_services,
        )
        self.get_models = to_raw_response_wrapper(
            health.get_models,
        )
        self.retrieve_status = to_raw_response_wrapper(
            health.retrieve_status,
        )
        self.retrieve_version = to_raw_response_wrapper(
            health.retrieve_version,
        )


class AsyncHealthResourceWithRawResponse:
    def __init__(self, health: AsyncHealthResource) -> None:
        self._health = health

        self.check_app = async_to_raw_response_wrapper(
            health.check_app,
        )
        self.check_models = async_to_raw_response_wrapper(
            health.check_models,
        )
        self.check_services = async_to_raw_response_wrapper(
            health.check_services,
        )
        self.get_models = async_to_raw_response_wrapper(
            health.get_models,
        )
        self.retrieve_status = async_to_raw_response_wrapper(
            health.retrieve_status,
        )
        self.retrieve_version = async_to_raw_response_wrapper(
            health.retrieve_version,
        )


class HealthResourceWithStreamingResponse:
    def __init__(self, health: HealthResource) -> None:
        self._health = health

        self.check_app = to_streamed_response_wrapper(
            health.check_app,
        )
        self.check_models = to_streamed_response_wrapper(
            health.check_models,
        )
        self.check_services = to_streamed_response_wrapper(
            health.check_services,
        )
        self.get_models = to_streamed_response_wrapper(
            health.get_models,
        )
        self.retrieve_status = to_streamed_response_wrapper(
            health.retrieve_status,
        )
        self.retrieve_version = to_streamed_response_wrapper(
            health.retrieve_version,
        )


class AsyncHealthResourceWithStreamingResponse:
    def __init__(self, health: AsyncHealthResource) -> None:
        self._health = health

        self.check_app = async_to_streamed_response_wrapper(
            health.check_app,
        )
        self.check_models = async_to_streamed_response_wrapper(
            health.check_models,
        )
        self.check_services = async_to_streamed_response_wrapper(
            health.check_services,
        )
        self.get_models = async_to_streamed_response_wrapper(
            health.get_models,
        )
        self.retrieve_status = async_to_streamed_response_wrapper(
            health.retrieve_status,
        )
        self.retrieve_version = async_to_streamed_response_wrapper(
            health.retrieve_version,
        )



# File generated from our OpenAPI spec by Stainless. See CONTRIBUTING.md for details.

from typing import TYPE_CHECKING, Dict, List, Optional

from pydantic import Field as FieldInfo

from ...._models import BaseModel

__all__ = ["SettingRetrieveResponse"]


class SettingRetrieveResponse(BaseModel):
    ai_mode: Optional[str] = None

    developer: Optional[bool] = None

    last_workspace: Optional[str] = None

    pinned_workspaces: Optional[List[str]] = None

    show_document_navigator: Optional[bool] = None

    show_help_page: Optional[bool] = None

    show_invite_tab: Optional[bool] = None

    show_security_settings: Optional[bool] = None

    show_smart_search: Optional[bool] = None

    show_templates: Optional[bool] = None

    show_thread_visualization: Optional[bool] = None

    if TYPE_CHECKING:
        # Some versions of Pydantic <2.8.0 have a bug and don’t allow assigning a
        # value to this field, so for compatibility we avoid doing it at runtime.
        __pydantic_extra__: Dict[str, object] = FieldInfo(init=False)  # pyright: ignore[reportIncompatibleVariableOverride]

        # Stub to indicate that arbitrary properties are accepted.
        # To access properties that are not valid identifiers you can use `getattr`, e.g.
        # `getattr(obj, '$type')`
        def __getattr__(self, attr: str) -> object: ...
    else:
        __pydantic_extra__: Dict[str, object]



# File generated from our OpenAPI spec by Stainless. See CONTRIBUTING.md for details.

from .document import (
    DocumentResource,
    AsyncDocumentResource,
    DocumentResourceWithRawResponse,
    AsyncDocumentResourceWithRawResponse,
    DocumentResourceWithStreamingResponse,
    AsyncDocumentResourceWithStreamingResponse,
)
from .annotation import (
    AnnotationResource,
    AsyncAnnotationResource,
    AnnotationResourceWithRawResponse,
    AsyncAnnotationResourceWithRawResponse,
    AnnotationResourceWithStreamingResponse,
    AsyncAnnotationResourceWithStreamingResponse,
)

__all__ = [
    "AnnotationResource",
    "AsyncAnnotationResource",
    "AnnotationResourceWithRawResponse",
    "AsyncAnnotationResourceWithRawResponse",
    "AnnotationResourceWithStreamingResponse",
    "AsyncAnnotationResourceWithStreamingResponse",
    "DocumentResource",
    "AsyncDocumentResource",
    "DocumentResourceWithRawResponse",
    "AsyncDocumentResourceWithRawResponse",
    "DocumentResourceWithStreamingResponse",
    "AsyncDocumentResourceWithStreamingResponse",
]



# File generated from our OpenAPI spec by Stainless. See CONTRIBUTING.md for details.

from typing import Optional

from ..._models import BaseModel

__all__ = ["TagUpdateResponse"]


class TagUpdateResponse(BaseModel):
    detail: str

    tag_id: str

    name: Optional[str] = None

    shared: Optional[bool] = None



# File generated from our OpenAPI spec by Stainless. See CONTRIBUTING.md for details.

from __future__ import annotations

from .doc_tag_response import DocTagResponse as DocTagResponse
from .annotation_create_params import AnnotationCreateParams as AnnotationCreateParams
from .annotation_update_params import AnnotationUpdateParams as AnnotationUpdateParams
from .annotation_delete_response import AnnotationDeleteResponse as AnnotationDeleteResponse



# File generated from our OpenAPI spec by Stainless. See CONTRIBUTING.md for details.

from typing import Optional
from datetime import date, datetime

from ..._models import BaseModel

__all__ = ["DocResponse"]


class DocResponse(BaseModel):
    created_at: datetime

    external_id: str

    title: str

    updated_at: datetime

    workspace_ext_id: str

    config_ext_id: Optional[str] = None

    created_by_ext_id: Optional[str] = None

    doc_date: Optional[date] = None

    file_name: Optional[str] = None

    file_size: Optional[int] = None

    file_type: Optional[str] = None

    n_chunks: Optional[int] = None

    n_pages: Optional[int] = None

    re_ocred: Optional[bool] = None

    shared: Optional[bool] = None

    status: Optional[str] = None

    storage_type: Optional[str] = None

    storage_uri: Optional[str] = None

    tokens: Optional[int] = None



# File generated from our OpenAPI spec by Stainless. See CONTRIBUTING.md for details.

from typing import List, Optional
from datetime import datetime

from ..._models import BaseModel

__all__ = ["WorkspaceGetTagsResponse", "Tag"]


class Tag(BaseModel):
    created_at: datetime

    created_by_ext_id: str

    name: str

    tag_ext_id: str

    type: str

    updated_at: datetime

    workspace_ext_id: str

    shared: Optional[bool] = None


class WorkspaceGetTagsResponse(BaseModel):
    tags: List[Tag]
